# QORE_FOUND - system has qore installed
# QORE_INCLUDE_DIR - includes
# QORE_INCLUDE_DIRS - cmake standard alias for QORE_INCLUDE_DIR
# QORE_LIBRARY - library location
# QORE_LIBRARIES - cmake standard alias for QORE_LIBRARY
#
# QORE_MODULES_DIR - location of qore modules
# QORE_API_VERSION - API version
#
# QORE_EXECUTABLE - qore interpret executable
# QORE_QPP_EXECUTABLE - qore qpp executable


if (CMAKE_VERSION VERSION_LESS 2.8.3)
    message(FATAL_ERROR "Qore requires at least CMake version 2.8.3")
endif()

set(QORE_FOUND 1)

set(QORE_INCLUDE_DIR /usr/local/include)
set(QORE_INCLUDE_DIRS ${QORE_INCLUDE_DIR})

find_library(QORE_LIBRARY NAMES qore libqore HINTS "/usr/local/lib/")
set(QORE_LIBRARIES ${QORE_LIBRARY})

set(QORE_MODULES_DIR /usr/local/lib/qore-modules)
set(QORE_USER_MODULES_DIR /usr/local/share/qore-modules)
set(QORE_USER_MODULES_VER_DIR /usr/local/share/qore-modules/0.8.12)
set(QORE_API_VERSION 0.19)

set(QORE_EXECUTABLE /usr/local/bin/qore)
set(QORE_QPP_EXECUTABLE /usr/local/bin/qpp)
set(QORE_QDX_EXECUTABLE /usr/local/bin/qdx)


# warning: the same prefix for current qore is ised if there is no
# CMAKE_INSTALL_PREFIX given
if (CMAKE_INSTALL_PREFIX_INITIALIZED_TO_DEFAULT)
    set(CMAKE_INSTALL_PREFIX /usr/local)
    message(STATUS "Using detected CMAKE_INSTALL_PREFIX: /usr/local")
endif (CMAKE_INSTALL_PREFIX_INITIALIZED_TO_DEFAULT)


if (NOT CMAKE_BUILD_TYPE)
    set(CMAKE_BUILD_TYPE "release")
endif (NOT CMAKE_BUILD_TYPE)
string(TOLOWER ${CMAKE_BUILD_TYPE} QORE_BUILD_TYPE_LWR)
if (${QORE_BUILD_TYPE_LWR} MATCHES "debug")
    add_definitions(-DDEBUG)
else ()
    add_definitions(-DNDEBUG)
endif ()


include("${CMAKE_CURRENT_LIST_DIR}/QoreMacros.cmake")
